# eric7.WebBrowser.Tools

Package containing tools for the QtWebEngine based browser.

### Modules

DelayedFileWatcher | Module implementing a file system watcher with a delay.
PrintToPdfDialog | Module implementing a dialog to enter the data for printing a web page to PDF.
Scripts | Module containing function to generate JavaScript code.
WebBrowserTools | Module implementing tool functions for the web browser.
WebHitTestResult | Module implementing an object for testing certain aspects of a web page.
WebIconDialog | Module implementing a dialog to manage the Favicons.
WebIconLoader | Module implementing an object to load web site icons.
WebIconProvider | Module containing a web site icon storage object.